@@ -72,7 +72,7 @@ CREATE FUNCTION pgroonga_snippet_html(target text, keywords text[], width intege
 
 CREATE FUNCTION pgroonga_highlight_html(target text, keywords text[])
 	RETURNS text
-	AS 'MODULE_PATHNAME', 'pgroonga_highlight_html'
+	AS 'MODULE_PATHNAME', 'pgroonga_highlight_html_text'
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
@@ -82,7 +82,25 @@ CREATE FUNCTION pgroonga_highlight_html(target text,
 				        keywords text[],
 				        indexName cstring)
 	RETURNS text
-	AS 'MODULE_PATHNAME', 'pgroonga_highlight_html'
+	AS 'MODULE_PATHNAME', 'pgroonga_highlight_html_text'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	PARALLEL SAFE;
+
+CREATE FUNCTION pgroonga_highlight_html(targets text[], keywords text[])
+	RETURNS text[]
+	AS 'MODULE_PATHNAME', 'pgroonga_highlight_html_text_array'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	PARALLEL SAFE;
+
+CREATE FUNCTION pgroonga_highlight_html(targets text[],
+				        keywords text[],
+				        indexName cstring)
+	RETURNS text[]
+	AS 'MODULE_PATHNAME', 'pgroonga_highlight_html_text_array'
 	LANGUAGE C
 	IMMUTABLE
 	STRICT
@@ -124,7 +142,8 @@ CREATE FUNCTION pgroonga_match_positions_character(target text,
 	STRICT
 	PARALLEL SAFE;
 
-CREATE FUNCTION pgroonga_query_extract_keywords(query text)
+CREATE FUNCTION pgroonga_query_extract_keywords(query text,
+						index_name text DEFAULT '')
 	RETURNS text[]
 	AS 'MODULE_PATHNAME', 'pgroonga_query_extract_keywords'
 	LANGUAGE C
@@ -1023,6 +1042,25 @@ CREATE OPERATOR &^ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_prefix_text_condition
+	(text, condition pgroonga_full_text_search_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_prefix_text_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &^ (
+	PROCEDURE = pgroonga_prefix_text_condition,
+	LEFTARG = text,
+	RIGHTARG = pgroonga_full_text_search_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_prefix_text_array(text[], text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_prefix_text_array'
@@ -1068,6 +1106,25 @@ CREATE OPERATOR &^ (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_prefix_varchar_condition
+	(target varchar, conditoin pgroonga_full_text_search_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_prefix_varchar_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &^ (
+	PROCEDURE = pgroonga_prefix_varchar_condition,
+	LEFTARG = varchar,
+	RIGHTARG = pgroonga_full_text_search_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
 CREATE FUNCTION pgroonga_prefix_varchar_array(varchar[], varchar)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_prefix_varchar_array'
@@ -1645,6 +1702,117 @@ CREATE OPERATOR &~| (
 	JOIN = contjoinsel
 );
 
+CREATE FUNCTION pgroonga_equal_text(target text, other text)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_text'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &= (
+	PROCEDURE = pgroonga_equal_text,
+	LEFTARG = text,
+	RIGHTARG = text,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
+CREATE FUNCTION pgroonga_equal_text_condition
+	(target text, condition pgroonga_full_text_search_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_text_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &= (
+	PROCEDURE = pgroonga_equal_text_condition,
+	LEFTARG = text,
+	RIGHTARG = pgroonga_full_text_search_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
+CREATE FUNCTION pgroonga_equal_varchar(target varchar, other varchar)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_varchar'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &= (
+	PROCEDURE = pgroonga_equal_varchar,
+	LEFTARG = varchar,
+	RIGHTARG = varchar,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
+CREATE FUNCTION pgroonga_equal_varchar_condition
+	(target varchar, condition pgroonga_full_text_search_condition)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_text_condition'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &= (
+	PROCEDURE = pgroonga_equal_varchar_condition,
+	LEFTARG = varchar,
+	RIGHTARG = pgroonga_full_text_search_condition,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
+CREATE FUNCTION pgroonga_equal_query_text_array(targets text[], query text)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_query_text_array'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &=~ (
+	PROCEDURE = pgroonga_equal_query_text_array,
+	LEFTARG = text[],
+	RIGHTARG = text,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
+CREATE FUNCTION pgroonga_equal_query_varchar_array(targets varchar[], query text)
+	RETURNS bool
+	AS 'MODULE_PATHNAME', 'pgroonga_equal_query_varchar_array'
+	LANGUAGE C
+	IMMUTABLE
+	STRICT
+	LEAKPROOF
+	PARALLEL SAFE
+	COST 300;
+
+CREATE OPERATOR &=~ (
+	PROCEDURE = pgroonga_equal_query_varchar_array,
+	LEFTARG = varchar[],
+	RIGHTARG = text,
+	RESTRICT = contsel,
+	JOIN = contjoinsel
+);
+
+
 DROP ACCESS METHOD IF EXISTS pgroonga CASCADE;
 CREATE FUNCTION pgroonga_handler(internal)
 	RETURNS index_am_handler
@@ -1760,6 +1928,14 @@ CREATE OPERATOR CLASS pgroonga_timestamptz_ops DEFAULT FOR TYPE timestamptz
 		OPERATOR 4 >=,
 		OPERATOR 5 >;
 
+CREATE OPERATOR CLASS pgroonga_uuid_ops DEFAULT FOR TYPE uuid
+	USING pgroonga AS
+		OPERATOR 1 <,
+		OPERATOR 2 <=,
+		OPERATOR 3 =,
+		OPERATOR 4 >=,
+		OPERATOR 5 >;
+
 CREATE FUNCTION pgroonga_match_script_jsonb(jsonb, text)
 	RETURNS bool
 	AS 'MODULE_PATHNAME', 'pgroonga_match_script_jsonb'
@@ -1855,7 +2031,10 @@ CREATE OPERATOR CLASS pgroonga_text_term_search_ops_v2 FOR TYPE text
 		OPERATOR 17 &^~,
 		OPERATOR 20 &^| (text, text[]),
 		OPERATOR 21 &^~| (text, text[]),
-		OPERATOR 36 !&^| (text, text[]);
+		OPERATOR 36 !&^| (text, text[]),
+		OPERATOR 37 &^ (text, pgroonga_full_text_search_condition),
+		OPERATOR 38 &=,
+		OPERATOR 39 &= (text, pgroonga_full_text_search_condition);
 
 CREATE OPERATOR CLASS pgroonga_text_array_term_search_ops_v2 FOR TYPE text[]
 	USING pgroonga AS
@@ -1865,7 +2044,8 @@ CREATE OPERATOR CLASS pgroonga_text_array_term_search_ops_v2 FOR TYPE text[]
 		OPERATOR 20 &^| (text[], text[]),
 		OPERATOR 21 &^~| (text[], text[]),
 		OPERATOR 24 &^> (text[], text), -- For backward compatibility
-		OPERATOR 25 &^~> (text[], text); -- For backward compatibility
+		OPERATOR 25 &^~> (text[], text), -- For backward compatibility
+		OPERATOR 40 &=~ (text[], text);
 
 CREATE OPERATOR CLASS pgroonga_text_regexp_ops_v2 FOR TYPE text
 	USING pgroonga AS
@@ -1886,7 +2066,10 @@ CREATE OPERATOR CLASS pgroonga_varchar_term_search_ops_v2
 		OPERATOR 16 &^,
 		OPERATOR 17 &^~,
 		OPERATOR 20 &^| (varchar, varchar[]),
-		OPERATOR 21 &^~| (varchar, varchar[]);
+		OPERATOR 21 &^~| (varchar, varchar[]),
+		OPERATOR 37 &^ (varchar, pgroonga_full_text_search_condition),
+		OPERATOR 38 &=,
+		OPERATOR 39 &= (varchar, pgroonga_full_text_search_condition);
 
 CREATE OPERATOR CLASS pgroonga_varchar_full_text_search_ops_v2
 	FOR TYPE varchar
@@ -1918,7 +2101,8 @@ CREATE OPERATOR CLASS pgroonga_varchar_array_term_search_ops_v2
 		OPERATOR 21 &^~| (varchar[], varchar[]),
 		OPERATOR 23 &> (varchar[], varchar),
 		OPERATOR 24 &^> (varchar[], varchar), -- For backward compatibility
-		OPERATOR 25 &^~> (varchar[], varchar); -- For backward compatibility
+		OPERATOR 25 &^~> (varchar[], varchar), -- For backward compatibility
+		OPERATOR 40 &=~ (varchar[], text);
 
 CREATE OPERATOR CLASS pgroonga_varchar_regexp_ops_v2 FOR TYPE varchar
 	USING pgroonga AS
@@ -2175,40 +2359,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.%% (
-				PROCEDURE = pgroonga.match_term,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.%% (
-				PROCEDURE = pgroonga.match_term,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.%% (
-				PROCEDURE = pgroonga.match_term,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.%% (
-				PROCEDURE = pgroonga.match_term,
-				LEFTARG = varchar[],
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.match_query(text, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_query_text'
@@ -2233,32 +2383,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.@@ (
-				PROCEDURE = pgroonga.match_query,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.@@ (
-				PROCEDURE = pgroonga.match_query,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.@@ (
-				PROCEDURE = pgroonga.match_query,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.match_regexp(text, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_regexp_text'
@@ -2275,24 +2399,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.@~ (
-				PROCEDURE = pgroonga.match_regexp,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.@~ (
-				PROCEDURE = pgroonga.match_regexp,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		/* v2 */
 		CREATE FUNCTION pgroonga.match_text(text, text)
 			RETURNS bool
@@ -2302,16 +2408,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&@ (
-				PROCEDURE = pgroonga.match_text,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.match_text_array(text[], text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_text_array'
@@ -2320,16 +2416,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&@ (
-				PROCEDURE = pgroonga.match_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.match_varchar(varchar, varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_varchar'
@@ -2338,16 +2424,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&@ (
-				PROCEDURE = pgroonga.match_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.contain_varchar_array(varchar[], varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_contain_varchar_array'
@@ -2356,16 +2432,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&> (
-				PROCEDURE = pgroonga.contain_varchar_array,
-				LEFTARG = varchar[],
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.match_jsonb(jsonb, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_jsonb'
@@ -2374,16 +2440,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&@ (
-				PROCEDURE = pgroonga.match_jsonb,
-				LEFTARG = jsonb,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.query_text(text, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_query_text'
@@ -2392,25 +2448,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&? (
-				PROCEDURE = pgroonga.query_text,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@~ (
-				PROCEDURE = pgroonga.query_text,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.query_text_array(text[], text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_query_text_array'
@@ -2419,25 +2456,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&? (
-				PROCEDURE = pgroonga.query_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@~ (
-				PROCEDURE = pgroonga.query_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.query_varchar(varchar, varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_query_varchar'
@@ -2446,25 +2464,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&? (
-				PROCEDURE = pgroonga.query_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@~ (
-				PROCEDURE = pgroonga.query_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.query_jsonb(jsonb, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_query_jsonb'
@@ -2473,25 +2472,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&? (
-				PROCEDURE = pgroonga.query_jsonb,
-				LEFTARG = jsonb,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@~ (
-				PROCEDURE = pgroonga.query_jsonb,
-				LEFTARG = jsonb,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.similar_text(text, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_similar_text'
@@ -2500,25 +2480,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&~? (
-				PROCEDURE = pgroonga.similar_text,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@* (
-				PROCEDURE = pgroonga.similar_text,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.similar_text_array(text[], text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_similar_text_array'
@@ -2527,25 +2488,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&~? (
-				PROCEDURE = pgroonga.similar_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@* (
-				PROCEDURE = pgroonga.similar_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.similar_varchar(varchar, varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_similar_varchar'
@@ -2554,25 +2496,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&~? (
-				PROCEDURE = pgroonga.similar_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@* (
-				PROCEDURE = pgroonga.similar_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.prefix_text(text, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_text'
@@ -2581,16 +2504,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&^ (
-				PROCEDURE = pgroonga.prefix_text,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.prefix_text_array(text[], text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_text_array'
@@ -2599,25 +2512,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&^ (
-				PROCEDURE = pgroonga.prefix_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			/* Deprecated since 1.2.1. */
-			CREATE OPERATOR public.&^> (
-				PROCEDURE = pgroonga.prefix_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.prefix_rk_text(text, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_rk_text'
@@ -2626,16 +2520,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&^~ (
-				PROCEDURE = pgroonga.prefix_rk_text,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.prefix_rk_text_array(text[], text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_rk_text_array'
@@ -2644,25 +2528,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&^~ (
-				PROCEDURE = pgroonga.prefix_rk_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			/* Deprecated since 1.2.1. */
-			CREATE OPERATOR public.&^~> (
-				PROCEDURE = pgroonga.prefix_rk_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.script_text(text, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_script_text'
@@ -2671,16 +2536,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&` (
-				PROCEDURE = pgroonga.script_text,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.script_text_array(text[], text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_script_text_array'
@@ -2689,16 +2544,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&` (
-				PROCEDURE = pgroonga.script_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.script_varchar(varchar, varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_script_varchar'
@@ -2707,16 +2552,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&` (
-				PROCEDURE = pgroonga.script_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.script_jsonb(jsonb, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_script_jsonb'
@@ -2725,16 +2560,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&` (
-				PROCEDURE = pgroonga.script_jsonb,
-				LEFTARG = jsonb,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.match_in_text(text, text[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_in_text'
@@ -2743,25 +2568,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			/* Deprecated since 1.2.1. */
-			CREATE OPERATOR public.&@> (
-				PROCEDURE = pgroonga.match_in_text,
-				LEFTARG = text,
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@| (
-				PROCEDURE = pgroonga.match_in_text,
-				LEFTARG = text,
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.match_in_text_array(text[], text[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_in_text_array'
@@ -2770,16 +2576,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&@| (
-				PROCEDURE = pgroonga.match_in_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.match_in_varchar(varchar, varchar[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_match_in_varchar'
@@ -2788,16 +2584,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&@| (
-				PROCEDURE = pgroonga.match_in_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.query_in_text(text, text[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_query_in_text'
@@ -2806,34 +2592,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			/* Deprecated since 1.2.1. */
-			CREATE OPERATOR public.&?> (
-				PROCEDURE = pgroonga.query_in_text,
-				LEFTARG = text,
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&?| (
-				PROCEDURE = pgroonga.query_in_text,
-				LEFTARG = text,
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@~| (
-				PROCEDURE = pgroonga.query_in_text,
-				LEFTARG = text,
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.query_in_text_array(text[], text[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_query_in_text_array'
@@ -2842,25 +2600,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&?| (
-				PROCEDURE = pgroonga.query_in_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@~| (
-				PROCEDURE = pgroonga.query_in_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.query_in_varchar(varchar, varchar[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_query_in_varchar'
@@ -2869,25 +2608,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			-- Deprecated since 1.2.2.
-			CREATE OPERATOR public.&?| (
-				PROCEDURE = pgroonga.query_in_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-
-			CREATE OPERATOR public.&@~| (
-				PROCEDURE = pgroonga.query_in_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.prefix_in_text(text, text[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_in_text'
@@ -2896,16 +2616,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&^| (
-				PROCEDURE = pgroonga.prefix_in_text,
-				LEFTARG = text,
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.prefix_in_text_array(text[], text[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_in_text_array'
@@ -2914,16 +2624,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&^| (
-				PROCEDURE = pgroonga.prefix_in_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.prefix_rk_in_text(text, text[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_rk_in_text'
@@ -2932,16 +2632,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&^~| (
-				PROCEDURE = pgroonga.prefix_rk_in_text,
-				LEFTARG = text,
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.prefix_rk_in_text_array(text[], text[])
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_prefix_rk_in_text_array'
@@ -2950,16 +2640,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&^~| (
-				PROCEDURE = pgroonga.prefix_rk_in_text_array,
-				LEFTARG = text[],
-				RIGHTARG = text[],
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.regexp_text(text, text)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_regexp_text'
@@ -2968,16 +2648,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&~ (
-				PROCEDURE = pgroonga.regexp_text,
-				LEFTARG = text,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE FUNCTION pgroonga.regexp_varchar(varchar, varchar)
 			RETURNS bool
 			AS 'MODULE_PATHNAME', 'pgroonga_regexp_varchar'
@@ -2986,17 +2656,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.&~ (
-				PROCEDURE = pgroonga.regexp_varchar,
-				LEFTARG = varchar,
-				RIGHTARG = varchar,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
-
 		/* v1 */
 		CREATE OPERATOR CLASS pgroonga.text_full_text_search_ops FOR TYPE text
 			USING pgroonga AS
@@ -3111,16 +2770,6 @@ BEGIN
 			STRICT
 			PARALLEL SAFE;
 
-		IF current_schema() <> 'public' THEN
-			CREATE OPERATOR public.@@ (
-				PROCEDURE = pgroonga.match_script_jsonb,
-				LEFTARG = jsonb,
-				RIGHTARG = text,
-				RESTRICT = contsel,
-				JOIN = contjoinsel
-			);
-		END IF;
-
 		CREATE OPERATOR CLASS pgroonga.jsonb_ops FOR TYPE jsonb
 			USING pgroonga AS
 				OPERATOR 9 @@ (jsonb, text),
@@ -3240,5 +2889,6 @@ BEGIN
 				OPERATOR 15 &` (jsonb, text),
 				OPERATOR 28 &@~ (jsonb, text);
 	END IF;
+
 END;
 $$;
